//! # Textcat
//!
//! Library to extract and categorize texts by ngrams.
#![deny(missing_docs)]
#![allow(warnings)]
pub mod category;
pub mod ngram;
